<template>
    <div class="dialog-table-container sub-page-inner">
        <div class="project-table">
            <!-- <el-button class="download" type="primary" icon="el-icon-view"
                @click="handleDetail('projectTrendChart')">查看指标趋势图</el-button> -->
            <el-table
                ref="expendTable"
                row-key="id"
                :element-loading-background="loadingColor"
                v-loading="loading"
                align="center"
                :data="tableData"
                height="calc(100% - 80PX)"
                class="dialog_table"
                :cell-style="{'text-align': 'center'}"
                :header-cell-style="{'text-align': 'center'}"
            >
                <el-table-column type="index" label="序号" width="60">
                </el-table-column>
                <el-table-column
                    prop="indexName"
                    label="核心指标"
                    min-width="320"
                >
                </el-table-column>
                <el-table-column prop="indexUnit" label="单位" width="80">
                </el-table-column>
                <el-table-column
                    prop="currentMonthTargetValue"
                    label="本月目标值"
                    width="150"
                >
                    <template v-slot="{row}">
                        {{
                            row.isYearOver === 2
                                ? row.currentMonthTargetValue
                                : '-'
                        }}
                    </template>
                </el-table-column>
                <el-table-column
                    prop="currentMonthRealValue"
                    label="本月完成值"
                    width="150"
                >
                    <template v-slot="{row}">
                        {{
                            row.isYearOver === 2 &&
                            (row.currentMonthRealValue ||
                                row.currentMonthRealValue === 0)
                                ? row.currentMonthRealValue
                                : '-'
                        }}
                    </template>
                </el-table-column>
                <el-table-column
                    prop="isCurrentMonthOver"
                    :label="`是否完成\n本月目标`"
                >
                    <template v-slot="{row}">
                        <el-tag
                            v-if="
                                row.isCurrentMonthOver == 1 &&
                                row.isYearOver === 2
                            "
                            type="success"
                            effect="dark"
                            >已完成</el-tag
                        >
                        <el-tag
                            v-if="
                                row.isCurrentMonthOver == 2 &&
                                row.isYearOver === 2
                            "
                            type="danger"
                            effect="dark"
                            >未完成</el-tag
                        >
                        <div v-if="row.isYearOver === 1">-</div>
                    </template>
                </el-table-column>

                <el-table-column
                    prop="upToMonthTargetValue"
                    label="累计月度目标值"
                    width="180"
                >
                    <template v-slot="{row}">
                        {{
                            row.isYearOver === 2
                                ? row.upToMonthTargetValue
                                : '-'
                        }}
                    </template>
                </el-table-column>
                <el-table-column
                    prop="upToMonthRealValue"
                    label="累计月度完成值"
                    width="160"
                >
                    <template v-slot="{row}">
                        {{
                            row.upToMonthRealValue ||
                            row.upToMonthRealValue === 0
                                ? row.upToMonthRealValue
                                : '-'
                        }}
                    </template>
                </el-table-column>
                <el-table-column
                    prop="isUpToMonthOver"
                    :label="`是否完成\n累计月度目标值`"
                >
                    <template v-slot="{row}">
                        <el-tag
                            v-if="
                                row.isUpToMonthOver == 1 && row.isYearOver === 2
                            "
                            type="success"
                            effect="dark"
                            >已完成</el-tag
                        >
                        <el-tag
                            v-if="
                                row.isUpToMonthOver == 2 && row.isYearOver === 2
                            "
                            type="danger"
                            effect="dark"
                            >未完成</el-tag
                        >
                        <div v-if="row.isYearOver === 1">-</div>
                    </template>
                </el-table-column>
                <el-table-column
                    prop="yearTargetValue"
                    label="年度目标"
                    width="110"
                >
                </el-table-column>
                <el-table-column
                    prop="isYearOver"
                    :label="`是否完成\n年度目标`"
                >
                    <template v-slot="{row}">
                        <el-tag
                            v-if="row.isYearOver == 1"
                            type="success"
                            effect="dark"
                            >已完成</el-tag
                        >
                        <el-tag
                            v-if="row.isYearOver == 2"
                            type="danger"
                            effect="dark"
                            >未完成</el-tag
                        >
                    </template>
                </el-table-column>
                <el-table-column
                    prop="monthAndYearRate"
                    :label="`达标率(%)`"
                    width="110"
                >
                    <template v-slot="{row}">
                        {{ row.monthAndYearRate }}%
                    </template>
                </el-table-column>
            </el-table>
        </div>
    </div>
</template>

<script>
import utils from '@/utils.js'
import pagenation from './pagenation.vue'
import apiList1 from '@/api/bigScreen/projectSub.js'
export default {
    components: {pagenation},
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            loading: false,
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                    showTotal: true,
                },
            },
            tableData: [],
            pieChart: null,
            pieChartOption: null,
            pieChartData: [
                {value: 0, name: '超额达成'},
                {value: 0, name: '达成'},
                {value: 0, name: '未达成'},
            ],
            chartLoading: false,
            ggbb_ssly: [],
            ggbb_cyzty: [],
            projectId: '',
            searchMonth: [],
            projectOptions: [],
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        this.projectId = this.$route.query.projectId
        this.ggbb_ssly = utils.getDictItemsFromCache('ggbb_ssly')
        this.ggbb_cyzty = utils.getDictItemsFromCache('ggbb_cyzty')
        this.getIndexLibrary(1)
        this.$bus.$on('changeDate', (searchDate) => {
            this.getIndexLibrary(1)
        })
        this.$emit('searchDateChange')
    },
    methods: {
        // 查询列表
        getIndexLibrary() {
            this.loading = true
            let data = JSON.parse(sessionStorage.getItem('searchDate'))
            data.projectId = this.projectId
            apiList1.quantifiedGoal(data, (res) => {
                if (res) {
                    this.tableData = res
                    this.params.pageBean.total = res
                    this.loading = false
                }
            })
        },
        handleDetail(comp) {
            this.$router.push({
                path: '/DetailComponent',
                name: 'DetailComponent',
                query: {
                    comp,
                    id: this.projectId,
                },
            })
        },
    },
}
</script>

<style lang="scss" scoped>
.flex {
    display: flex;
}

.table-contaier {
    height: calc(100% - 130PX);
}

// .dialog-table-container {
// //   width: calc(100% - 400PX);
// //   height: 550PX;
// }
.dialog-chart-contaienr {
    width: 400PX;
    height: 550PX;
}

.chart-content {
    width: 100%;
    height: 50%;
}

#pieChart {
    width: 100%;
    height: calc(100% - 40PX);
}

.sub-title {
    width: 100%;
    height: 18PX;
    text-align: center;
    position: relative;
    font-size: 14PX;
    font-family: SimHei;
    font-weight: 800;
    color: #ffffff;
    text-shadow: 0PX 0PX 16PX #266bf2;
    margin-bottom: 10PX;
}

.sub-title::after,
.sub-title::before {
    content: '';
    position: absolute;
    top: 47%;
    width: 40PX;
    height: 4PX;
}

.sub-title::before {
    left: 32%;
    background: url('~@/assets/img/bigScreen/line63.png') no-repeat center / 100% 100%;
}

.sub-title::after {
    right: 32%;
    background: url('~@/assets/img/bigScreen/line62.png') no-repeat center / 100% 100%;
}

.item-container {
    display: flex;
    justify-content: start;
    margin-left: 20PX;
}

.manager-item-text {
    display: flex;
    align-items: center;
    font-size: 14PX;
    font-weight: 400;
    color: #fff;
    width: 160PX;
    border-bottom: 1PX solid #266bf2;
    justify-content: start;
    box-sizing: border-box;
    padding-left: 15PX;
    position: relative;
}

.manager-item-text.item-1 {
    margin-top: 15PX;
}

.manager-item-text.item-2 {
    margin-left: -15PX;
    padding-left: 25PX;
}

.manager-item-text.item-3 {
    margin-left: -30PX;
    padding-left: 25PX;
}

.manager-item-text.item-4 {
    margin-left: -45PX;
    padding-left: 25PX;
}

.manager-item-text:before {
    content: '';
    position: absolute;
    left: 0%;
    bottom: -5PX;
    width: 10PX;
    height: 10PX;
    background-color: #266bf2;
    border-radius: 10PX;
}

.manager-item-text:after {
    content: '';
    position: absolute;
    right: 0%;
    bottom: -5PX;
    width: 10PX;
    height: 10PX;
    background-color: #266bf2;
    border-radius: 10PX;
}

/deep/ .dialog-table-expand label {
    width: 120PX;
    color: #fff;
    font-family: SimHei;
}

/deep/ .el-input__inner {
    background-color: rgba(1, 47, 115, 0.6);
    border: 1PX solid #0273e9;
    color: #fff;
    font-size: 16PX;
    height: 34PX;
    line-height: 34PX;
}

/deep/ .el-date-editor .el-range-input {
    background-color: transparent;
    color: #fff;
}

/deep/ .el-date-editor .el-range-separator {
    color: #fff;
}

.pie-box {
    width: 30%;
    display: flex;
    align-items: center;
    justify-content: center;
}

#pie {
    width: 100%;
    margin: 0 auto;
    height: 40vh;
}

.project-table {
    margin-top: 20PX;
    width: 100%;
    // width: 65%;
}

.flex-start {
    width: 100%;
    display: flex;
    justify-content: start;
    align-items: center;
}
</style>
<style lang="scss">
@import './table.scss';
</style>
